/*
 * JBoss, Home of Professional Open Source
 *
 * Copyright 2013 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.picketlink.identity.federation.core.wstrust;

/**
 * <p>
 * Interface that represents a security token.
 * </p>
 *
 * @author <a href="mailto:sguilhen@redhat.com">Stefan Guilhen</a>
 */
public interface SecurityToken {

    /**
     * <p>
     * Obtains the security token unique identifier.
     * </p>
     *
     * @return a {@code String} representing the token id.
     */
    String getTokenID();

    /**
     * <p>
     * Obtains the type of the security token.
     * </p>
     *
     * @return a {@code String} representing the security token type.
     */
    String getTokenType();

    /**
     * <p>
     * Obtains the value of the security token.
     * </p>
     *
     * @return an {@code Object} representing the security token value.
     */
    Object getTokenValue();
}
